//###########################################################################
//
// FILE:   F2812_3ADS8365_Main.c
//
// TITLE:  DSP281x Plus 3pcs ADS8365 project
//
// ASSUMPTIONS:
//
//          This program requires the DSP281x V1.00 header files.  
//          As supplied, this project is configured for "boot to Flash" operation.   
//
//          This example runs the EV Timer Period example from the 
//          Flash.  
//
//          1) Build the project
//          2) Flash the .out file into the device.  This program will fit on 
//             an F2812 or an F2810
//          3) Set the hardware jumpers to boot to Flash 
//          4) Use the included GEL file to load the project, symbols 
//             defined within the project and the variables into the watch
//             window.   
//
//          Steps that were taken to convert the EV example from RAM 
//          to Flash execution:
//
//          - Change the linker cmd file to reflect the flash memory map.
//            This example uses the DSP281x F2812.cmd file.
//          - Make sure any initialized sections are mapped to Flash.  
//            In SDFlash utility this can be checked by the View->Coff/Hex
//            status utility. Any section marked as "load" should be
//            allocated to Flash.
//          - Make sure there is a branch instruction from the entry to Flash
//            at 0x3F7FF6 to the beginning of code execution. This example
//            uses the DSP281x_CodeStartBranch.asm file to accomplish this.
//          - Set boot mode Jumpers to "boot to Flash"
//          - For best performance from the flash, modify the waitstates
//            and enable the flash pipeline as shown in this example.
//            Note: any code that manipulates the flash waitstate and pipeline
//            control must be run from RAM. Thus these functions are located
//            in their own memory section called ramfuncs.
// 
// DESCRIPTION:
//
//          This program sets up EVA Timer 1, EVA Timer 2, EVB Timer 3
//          and EVB Timer 4 to fire an interrupt on a period overflow.  
//          A count is kept each time each interrupt passes through
//          the interrupt service routine. 
//
//          EVA Timer 1 has the shortest period while EVB Timer4 has the
//          longest period.
//
//          ISR Locations:
//                eva_timer1_isr  executed from RAM, puts flash in sleep mode
//                eva_timer2_isr  executed from RAM, puts flash in standby mode
//                evb_timer3_isr  executed from RAM, puts flash in sleep mode
//                                              and later moves it to standby
//                evb_timer4_isr  executed from FLASH
//        
//          Watch Variables:
//
//                EvaTimer1InterruptCount;
//                EvaTimer2InterruptCount;
//                EvbTimer3InterruptCount;
//                EvbTimer4InterruptCount;
//
//###########################################################################
//
//  Ver | dd mmm yyyy | Who  | Description of changes
// =====|=============|======|===============================================
//  1.00| 11 Sep 2003 | L.H. | Changes since previous version (v.58 Alpha)
//      |             |      | Updated comments with info on converting
//      |             |      |   a project to flash.
//      |             |      | Changed the method for copying code from
//      |             |      |    XINTF to internal RAM via the MemCopy
//      |             |      |    function and symbols created by the 
//      |             |      |    linker.
//###########################################################################

#include "DSP281x_Device.h"     // DSP281x Headerfile Include File
#include "DSP281x_Setting.h"   	// DSP281x Examples Include File

// Functions that will be run from RAM need to be assigned to 
// a different section.  This section will then be mapped using
// the linker cmd file.			// 


// Prototype statements for functions found within this file.
void read_ADS8365(int adc);
void Reset_ADS8365(int adc);
void Toggle_HOLDx(int channel);

// Global variables used in this example
Uint32 EvaTimer1InterruptCount;
Uint32 EvbTimer3InterruptCount;
Uint32 LoopCount;

#if	FLASH_MODE == SET_YES
// These are defined by the linker (see F2812.cmd)
extern Uint16 RamfuncsLoadStart;
extern Uint16 RamfuncsLoadEnd;
extern Uint16 RamfuncsRunStart;
#endif

unsigned int ADS8365_Debug;
unsigned int ADS8365_Ready;

int	ADC_Ch_A0[ADC_NUM][ADC_DATA_NUM];
int	ADC_Ch_A1[ADC_NUM][ADC_DATA_NUM];
int	ADC_Ch_B0[ADC_NUM][ADC_DATA_NUM];
int	ADC_Ch_B1[ADC_NUM][ADC_DATA_NUM];
int	ADC_Ch_C0[ADC_NUM][ADC_DATA_NUM];
int ADC_Ch_C1[ADC_NUM][ADC_DATA_NUM];

int	ADC_ErrA0_Dat0[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrA1_Dat0[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrB0_Dat0[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrB1_Dat0[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrC0_Dat0[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrC1_Dat0[ADC_NUM][ADC_ERR_NUM];

int	ADC_ErrA0_Dat1[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrA1_Dat1[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrB0_Dat1[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrB1_Dat1[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrC0_Dat1[ADC_NUM][ADC_ERR_NUM];
int	ADC_ErrC1_Dat1[ADC_NUM][ADC_ERR_NUM];

int ADC_ErrA0_Num[ADC_NUM][ADC_ERR_NUM];	//
int ADC_ErrA1_Num[ADC_NUM][ADC_ERR_NUM];	//
int ADC_ErrB0_Num[ADC_NUM][ADC_ERR_NUM];	//
int ADC_ErrB1_Num[ADC_NUM][ADC_ERR_NUM];	//
int ADC_ErrC0_Num[ADC_NUM][ADC_ERR_NUM];	//
int ADC_ErrC1_Num[ADC_NUM][ADC_ERR_NUM];	//

unsigned int ADC_ErrA0_Count[ADC_NUM];
unsigned int ADC_ErrA1_Count[ADC_NUM];
unsigned int ADC_ErrB0_Count[ADC_NUM];
unsigned int ADC_ErrB1_Count[ADC_NUM];
unsigned int ADC_ErrC0_Count[ADC_NUM];
unsigned int ADC_ErrC1_Count[ADC_NUM];

unsigned int ADC_EOC_Flag[ADC_NUM];
unsigned int ADC_Data_Count[ADC_NUM];
unsigned int ADC_Sample_Count[ADC_NUM];

unsigned int ADC_Err1_Flag;
unsigned int ADC_Err2_Flag;
unsigned int adc_order;

int *ptrCHA0[ADC_NUM];
int *ptrCHA1[ADC_NUM];
int *ptrCHB0[ADC_NUM];
int *ptrCHB1[ADC_NUM];
int *ptrCHC0[ADC_NUM];
int *ptrCHC1[ADC_NUM];

void main(void)
{
// Step 1. Initialize System Control:
// PLL, WatchDog, enable Peripheral Clocks
// This example function is found in the DSP281x_SysCtrl.c file.
   	InitSysCtrl();
   
// Step 2. Initalize GPIO: 
// This example function is found in the DSP281x_Gpio.c file and
// illustrates how to set the GPIO to it's default state.
	InitGpio();  // Skipped for this example  

// Step 3. Clear all interrupts and initialize PIE vector table:
// Disable CPU interrupts 
   	DINT;

// Initialize PIE control registers to their default state.
// The default state is all PIE interrupts disabled and flags
// are cleared.  
// This function is found in the DSP281x_PieCtrl.c file.
   	InitPieCtrl();

// Disable CPU interrupts and clear all CPU interrupt flags:
   	IER = 0x0000;
   	IFR = 0x0000;

// Initialize the PIE vector table with pointers to the shell Interrupt 
// Service Routines (ISR).  
// This will populate the entire table, even if the interrupt
// is not used in this example.  This is useful for debug purposes.
// The shell ISR routines are found in DSP281x_DefaultIsr.c.
// This function is found in DSP281x_PieVect.c.
   	InitPieVectTable();

// Interrupts that are used in this example are re-mapped to
// ISR functions found within this file.  	
   	EALLOW;  // This is needed to write to EALLOW protected registers
// 	PieVectTable.T1PINT = &EvaTimer1_Isr;
// 	PieVectTable.T2PINT = &EvaTimer2_Isr;
   	PieVectTable.T3PINT = &EvbTimer3_Isr;

#if	CAPINT_MODE == SET_YES
   	PieVectTable.CAPINT1 = &EvaCap1_Isr;
   	PieVectTable.CAPINT2 = &EvaCap2_Isr;
   	PieVectTable.CAPINT3 = &EvaCap3_Isr;
#endif

   	EDIS;   // This is needed to disable write to EALLOW protected registers

// Step 4. Initialize all the Device Peripherals:
// This function is found in DSP281x_InitPeripherals.c
// InitPeripherals(); // Not required for this example
   	InitEva_Timer1();
   	InitEva_Timer2();
   	InitEvb_Timer3();		// PWM7 as Hold control for U2-ADS8365)
     
// Step 5. User specific code, enable interrupts:
#if	FLASH_MODE == SET_YES
// Copy time critical code and Flash setup code to RAM
// This includes the following ISR functions: EvaTimer1(), EvaTimer2()
// EvbTimer3 and and InitFlash();
// The  RamfuncsLoadStart, RamfuncsLoadEnd, and RamfuncsRunStart
// symbols are created by the linker. Refer to the F2812.cmd file. 
   	MemCopy(&RamfuncsLoadStart, &RamfuncsLoadEnd, &RamfuncsRunStart);
// Call Flash Initialization to setup flash waitstates
// This function must reside in RAM
   	InitFlash();
#endif

 	InitXintf();

   // Initialize count values to 0
    EvaTimer1InterruptCount = 0;
    EvbTimer3InterruptCount = 0;
   	LoopCount = 0;
	adc_order = 3;
	
	ptrCHA0[0] = (int *)ADC0_CHA0;
	ptrCHA1[0] = (int *)ADC0_CHA1;
	ptrCHB0[0] = (int *)ADC0_CHB0;
	ptrCHB1[0] = (int *)ADC0_CHB1;
	ptrCHC0[0] = (int *)ADC0_CHC0;
	ptrCHC1[0] = (int *)ADC0_CHC1;

	ptrCHA0[1] = (int *)ADC1_CHA0;
	ptrCHA1[1] = (int *)ADC1_CHA1;
	ptrCHB0[1] = (int *)ADC1_CHB0;
	ptrCHB1[1] = (int *)ADC1_CHB1;
	ptrCHC0[1] = (int *)ADC1_CHC0;
	ptrCHC1[1] = (int *)ADC1_CHC1;

	ptrCHA0[2] = (int *)ADC2_CHA0;
	ptrCHA1[2] = (int *)ADC2_CHA1;
	ptrCHB0[2] = (int *)ADC2_CHB0;
	ptrCHB1[2] = (int *)ADC2_CHB1;
	ptrCHC0[2] = (int *)ADC2_CHC0;
	ptrCHC1[2] = (int *)ADC2_CHC1;

// Hardware Reset the ADS8365:
	Reset_ADS8365(ADS8365_U2);
	Reset_ADS8365(ADS8365_U3);
	Reset_ADS8365(ADS8365_U4);

#if	CAPINT_MODE == SET_YES
   // Enable PIE group 3 interrupt 5, 6, 7 for CAP1INT, CAP2INT, CAP3INT
   	PieCtrlRegs.PIEIER3.all |= (M_INT5 | M_INT6 | M_INT7);

   // Enable PIE group 4 interrupt 4 for T3PINT
   	PieCtrlRegs.PIEIER4.all = M_INT4;

   // Enable CPU INT3 for CAP1INT, CAP2INT, CAP3INT, INT4 for T3PINT
   	IER |= (M_INT3 | M_INT4);
#endif

#if	CAPINT_MODE == SET_NO
   // Enable PIE group 4 interrupt 4 for T3PINT
   	PieCtrlRegs.PIEIER4.all = M_INT4;

   // Enable CPU INT4 for T3PINT
   	IER |= M_INT4;
#endif

	//Delay 200ms
	DELAY_US(50000);         // Delay 50000us
	DELAY_US(50000);         // Delay 50000us
	DELAY_US(50000);         // Delay 50000us
	DELAY_US(50000);         // Delay 50000us
	
	ADS8365_Ready = 1;
	ADS8365_Debug = 0;

  	EnableInterrupts();

   // Enable global Interrupts and higher priority real-time debug events:
   	EINT;   // Enable Global interrupt INTM
  	ERTM;   // Enable Global realtime interrupt DBGM


// Step 6. IDLE loop. Just sit and loop forever:	
   	while(1)
   	{
	    LoopCount++;

// Check initially for RESET, then after each read
		if (ADS8365_Debug)
		{	
			DELAY_US(5);         // Delay 5us
			read_ADS8365(ADS8365_U2);		
			read_ADS8365(ADS8365_U3);		
			read_ADS8365(ADS8365_U4);		
		}

		if(LoopCount >= 5000)
			LoopCount = 0;
   	}

} 

// Read Function called from ISR in ADS8364_DefaultISR.c
/*******************************************************************************
 FUNC	: read_ADD
 DESC	: Prepare the system for the ADC conversions. Everything is set up to
 		  wait the CONV CLK start running (TIMER0)
 ARGS	: void
 RET	: void
 *******************************************************************************/
void read_ADS8365(int adc)
{
	unsigned int ADC_Data_Comp;
	
	ADC_Ch_A0[adc][ADC_Data_Count[adc]] = *ptrCHA0[adc];
    asm (" RPT #1 || NOP");
	ADC_Ch_A1[adc][ADC_Data_Count[adc]] = *ptrCHA1[adc];
    asm (" RPT #1 || NOP");
	ADC_Ch_B0[adc][ADC_Data_Count[adc]] = *ptrCHB0[adc];
    asm (" RPT #1 || NOP");
	ADC_Ch_B1[adc][ADC_Data_Count[adc]] = *ptrCHB1[adc];
    asm (" RPT #1 || NOP");
	ADC_Ch_C0[adc][ADC_Data_Count[adc]] = *ptrCHC0[adc];
    asm (" RPT #1 || NOP");
	ADC_Ch_C1[adc][ADC_Data_Count[adc]] = *ptrCHC1[adc];

	ADC_Err1_Flag = 0;
	ADC_Err2_Flag = 0;
	adc_order = adc;

	if(ADC_Sample_Count[adc] >= 10)
	{
		if(ADC_Data_Count[adc]==0)
			ADC_Data_Comp = ADC_DATA_NUM - 1;
		else
			ADC_Data_Comp = ADC_Data_Count[adc] -1;
	
	// Check ADS8365 A0 Channel Convert Result	
		if(abs(ADC_Ch_A0[adc][ADC_Data_Count[adc]]-ADC_Ch_A0[adc][ADC_Data_Comp])>4096)
		{
			ADC_Err1_Flag = 1;			
			ADC_ErrA0_Dat0[adc][ADC_ErrA0_Count[adc]] = ADC_Ch_A0[adc][ADC_Data_Count[adc]];
			ADC_ErrA0_Dat1[adc][ADC_ErrA0_Count[adc]] = ADC_Ch_A0[adc][ADC_Data_Comp];

			ADC_ErrA0_Count[adc]++;
			ADC_ErrA0_Num[adc][ADC_ErrA0_Count[adc]]=ADC_Data_Count[adc];				

			if(ADC_ErrA0_Count[adc]>=ADC_ERR_NUM)
				ADC_ErrA0_Count[adc] = 0;

			if(ADC_Ch_A0[adc][ADC_Data_Count[adc]] == 0x00000 || ADC_Ch_A0[adc][ADC_Data_Count[adc]] == 0x0FFFF)
				ADC_Err2_Flag = 1;			
		}

	// Check ADS8365 A1 Channel Convert Result	
		if(abs(ADC_Ch_A1[adc][ADC_Data_Count[adc]]-ADC_Ch_A1[adc][ADC_Data_Comp])>4096)
		{
			ADC_Err1_Flag = 1;			
			
			ADC_ErrA1_Dat0[adc][ADC_ErrA1_Count[adc]] = ADC_Ch_A1[adc][ADC_Data_Count[adc]];
			ADC_ErrA1_Dat1[adc][ADC_ErrA1_Count[adc]] = ADC_Ch_A1[adc][ADC_Data_Comp];

			ADC_ErrA1_Count[adc]++;
			ADC_ErrA1_Num[adc][ADC_ErrA1_Count[adc]]=ADC_Data_Count[adc];				

			if(ADC_ErrA1_Count[adc]>=ADC_ERR_NUM)
				ADC_ErrA1_Count[adc] = 0;

			if(ADC_Ch_A1[adc][ADC_Data_Count[adc]] == 0x00000 || ADC_Ch_A1[adc][ADC_Data_Count[adc]] == 0x0FFFF)
				ADC_Err2_Flag = 1;			
		}

	// Check ADS8365 B0 Channel Convert Result	
		if(abs(ADC_Ch_B0[adc][ADC_Data_Count[adc]]-ADC_Ch_B0[adc][ADC_Data_Comp])>4096)
		{
			ADC_Err1_Flag = 1;			

			ADC_ErrB0_Dat0[adc][ADC_ErrB0_Count[adc]] = ADC_Ch_B0[adc][ADC_Data_Count[adc]];
			ADC_ErrB0_Dat1[adc][ADC_ErrB0_Count[adc]] = ADC_Ch_B0[adc][ADC_Data_Comp];

			ADC_ErrB0_Count[adc]++;
			ADC_ErrB0_Num[adc][ADC_ErrB0_Count[adc]]=ADC_Data_Count[adc];				

			if(ADC_ErrB0_Count[adc]>=ADC_ERR_NUM)
				ADC_ErrB0_Count[adc] = 0;

			if(ADC_Ch_B0[adc][ADC_Data_Count[adc]] == 0x00000 || ADC_Ch_B0[adc][ADC_Data_Count[adc]] == 0x0FFFF)
				ADC_Err2_Flag = 1;			
		}

	// Check ADS8365 B1 Channel Convert Result	
		if(abs(ADC_Ch_B1[adc][ADC_Data_Count[adc]]-ADC_Ch_B1[adc][ADC_Data_Comp])>4096)
		{
			ADC_Err1_Flag = 1;			

			ADC_ErrB1_Dat0[adc][ADC_ErrB1_Count[adc]] = ADC_Ch_B1[adc][ADC_Data_Count[adc]];
			ADC_ErrB1_Dat1[adc][ADC_ErrB1_Count[adc]] = ADC_Ch_B1[adc][ADC_Data_Comp];

			ADC_ErrB1_Count[adc]++;
			ADC_ErrB1_Num[adc][ADC_ErrB1_Count[adc]]=ADC_Data_Count[adc];				

			if(ADC_ErrB1_Count[adc]>=ADC_ERR_NUM)
				ADC_ErrB1_Count[adc] = 0;

			if(ADC_Ch_B1[adc][ADC_Data_Count[adc]] == 0x00000 || ADC_Ch_B1[adc][ADC_Data_Count[adc]] == 0x0FFFF)
				ADC_Err1_Flag = 1;			
		}

	// Check ADS8365 C0 Channel Convert Result	
		if(abs(ADC_Ch_C0[adc][ADC_Data_Count[adc]]-ADC_Ch_C0[adc][ADC_Data_Comp])>4096)
		{
			ADC_Err1_Flag = 1;			

			ADC_ErrC0_Dat0[adc][ADC_ErrC0_Count[adc]] = ADC_Ch_C0[adc][ADC_Data_Count[adc]];
			ADC_ErrC0_Dat1[adc][ADC_ErrC0_Count[adc]] = ADC_Ch_C0[adc][ADC_Data_Comp];

			ADC_ErrC0_Count[adc]++;
			ADC_ErrC0_Num[adc][ADC_ErrC0_Count[adc]]=ADC_Data_Count[adc];				

			if(ADC_ErrC0_Count[adc]>=ADC_ERR_NUM)
				ADC_ErrC0_Count[adc] = 0;

			if(ADC_Ch_C0[adc][ADC_Data_Count[adc]] == 0x00000 || ADC_Ch_C0[adc][ADC_Data_Count[adc]] == 0x0FFFF)
				ADC_Err2_Flag = 1;			
		}

	// Check ADS8365 C1 Channel Convert Result	
		if(abs(ADC_Ch_C1[adc][ADC_Data_Count[adc]]-ADC_Ch_C1[adc][ADC_Data_Comp])>4096)
		{
			ADC_Err1_Flag = 1;			

			ADC_ErrC1_Dat0[adc][ADC_ErrC1_Count[adc]] = ADC_Ch_C1[adc][ADC_Data_Count[adc]];
			ADC_ErrC1_Dat1[adc][ADC_ErrC1_Count[adc]] = ADC_Ch_C1[adc][ADC_Data_Comp];

			ADC_ErrC1_Count[adc]++;
			ADC_ErrC1_Num[adc][ADC_ErrC1_Count[adc]]=ADC_Data_Count[adc];				

			if(ADC_ErrC1_Count[adc]>=ADC_ERR_NUM)
				ADC_ErrC1_Count[adc] = 0;

			if(ADC_Ch_C1[adc][ADC_Data_Count[adc]] == 0x00000 || ADC_Ch_C1[adc][ADC_Data_Count[adc]] == 0x0FFFF)
				ADC_Err2_Flag = 1;			
		}

	}

	if(ADC_Err1_Flag == 1)
	{
		ADC_Err1_Flag = 0;
	 	GpioDataRegs.GPADAT.bit.GPIOA12 = 1;		// A12=1

		if(adc==ADS8365_U2)
	 		GpioDataRegs.GPADAT.bit.GPIOA2 = 1;		// A2=1

		if(adc==ADS8365_U3)
	 		GpioDataRegs.GPADAT.bit.GPIOA3 = 1;		// A3=1

		if(adc==ADS8365_U4)
	 		GpioDataRegs.GPADAT.bit.GPIOA4 = 1;		// A4=1
	}

	if(ADC_Err2_Flag == 1)
	{
		ADC_Err2_Flag = 0;
		if(adc==ADS8365_U2)
	 		GpioDataRegs.GPADAT.bit.GPIOA13 = 1;		// A13=1

		if(adc==ADS8365_U3)
	 		GpioDataRegs.GPADAT.bit.GPIOA14 = 1;		// A14=1

		if(adc==ADS8365_U4)
	 		GpioDataRegs.GPADAT.bit.GPIOA15 = 1;		// A15=1
	}
	
	ADC_Data_Count[adc]++;
	if(ADC_Data_Count[adc]>=ADC_DATA_NUM)
		ADC_Data_Count[adc] = 0;

	ADC_Sample_Count[adc]++;
	if(ADC_Sample_Count[adc]>=5000)
		ADC_Sample_Count[adc] = 50;

}

void Reset_ADS8365(int adc)
{	
	unsigned int i;

	ADC_EOC_Flag[adc] = 0;
	ADC_Data_Count[adc] = 0;
	ADC_Sample_Count[adc] = 0;

	ADC_ErrA0_Count[adc] = 0;
	ADC_ErrA1_Count[adc] = 0;
	ADC_ErrB0_Count[adc] = 0;
	ADC_ErrB1_Count[adc] = 0;
	ADC_ErrC0_Count[adc] = 0;
	ADC_ErrC1_Count[adc] = 0;

	for(i=0;i<ADC_ERR_NUM;i++)
	{
		ADC_ErrA0_Dat0[adc][i]=1;
		ADC_ErrA1_Dat0[adc][i]=1;
		ADC_ErrB0_Dat0[adc][i]=1;
		ADC_ErrB1_Dat0[adc][i]=1;
		ADC_ErrC0_Dat0[adc][i]=1;
		ADC_ErrC1_Dat0[adc][i]=1;

		ADC_ErrA0_Dat1[adc][i]=1;
		ADC_ErrA1_Dat1[adc][i]=1;
		ADC_ErrB0_Dat1[adc][i]=1;
		ADC_ErrB1_Dat1[adc][i]=1;
		ADC_ErrC0_Dat1[adc][i]=1;
		ADC_ErrC1_Dat1[adc][i]=1;

	 	ADC_ErrA0_Num[adc][i]=1;	//
		ADC_ErrA1_Num[adc][i]=1;	//
		ADC_ErrB0_Num[adc][i]=1;	//
		ADC_ErrB1_Num[adc][i]=1;	//
		ADC_ErrC0_Num[adc][i]=1;	//
		ADC_ErrC1_Num[adc][i]=1;	//
	}

	for(i=0;i<ADC_DATA_NUM;i++)
	{
		ADC_Ch_A0[adc][i] = 1;
		ADC_Ch_A1[adc][i] = 1;
		ADC_Ch_B0[adc][i] = 1;
		ADC_Ch_B1[adc][i] = 1;
		ADC_Ch_C0[adc][i] = 1;
		ADC_Ch_C1[adc][i] = 1;
	}


//  GpioDataRegs.GPFCLEAR.all = 0x0001;  // Test Clear    
    asm (" RPT #200 || NOP");
//  GpioDataRegs.GPFSET.all = 0x0001;    // Test Set
}	

void ToggleHOLDx(int channel)
{
//  GpioDataRegs.GPACLEAR.all = channel;  // Test Clear    
    asm (" RPT #25 || NOP");
//  GpioDataRegs.GPASET.all = channel;    // Test Set
}	
	

//===========================================================================
// No more.
//===========================================================================
